---
title: "Double Cropping - BrazilAgriAnalysis"
author: "James D.A. Millington"
date: "June 2019"
output: 
  html_document: 
    keep_md: yes
    code_folding: hide
    df_print: paged
---



```r
rm(list=ls())
library(tidyverse)
library(readxl)
```


## Harvested Area

Data from IBGE

```r
##Load Area Harvested Data

#maize data are by municiaplity for all states (Amunis)
maize_harv_Amunis_Data <- read_excel("ProductionData/maize_brazil.xlsx", sheet = "Harvested area (hectares)", skip = 1, na = c("", "-", "..."))

#maize data are by municiaplity for all states (Amunis)
maize2_harv_Amunis_Data <- read_excel("ProductionData/maize2_brazil.xlsx", sheet = "Harvested area (hectares)", skip = 1, na = c("", "-", "..."), col_types = c("numeric", "guess","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric"))  #need to specify for 2010 column  

#maize data are by municiaplity for all states (Amunis)
soy_harv_Amunis_Data <- read_excel("ProductionData/soybean_brazil.xlsx", sheet = "Harvested area (hectares)", skip = 1, na = c("", "-", "..."))


Fstate_vals <- c(17,	29,	31,	35,	41,	42,	43,	50,	51,	52)
Fstate_abbrev <- c("TO", "BA", "MG", "SP", "PR",  "SC", "RS", "MS", "MT", "GO")
```



```r
#Manipulate data

#MAIZE
#has the same data strucutre (with some differences in unit conversions - could write function to cover both?) 
maize_harv_Amunis <- maize_harv_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2001":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

maize_harv_Astates <- maize_harv_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

maize_harv_Astates_long <- maize_harv_Astates %>%
  gather(key = year, value = maize_ha, -state) %>%
  mutate_at(vars(year), as.integer)

maize_harv_Amunis_long <- maize_harv_Amunis %>%
  dplyr::select(-state) %>%
  gather(key = year, value = maize_ha, -muniID) %>%
  mutate_at(vars(year), as.integer)

#MAIZE2
maize2_harv_Amunis <- maize2_harv_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2003":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

maize2_harv_Astates <- maize2_harv_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

maize2_harv_Astates_long <- maize2_harv_Astates %>%
  gather(key = year, value = maize2_ha, -state) %>%
  mutate_at(vars(year), as.integer)

maize2_harv_Amunis_long <- maize2_harv_Amunis %>%
  dplyr::select(-state) %>%
  gather(key = year, value = maize2_ha, -muniID) %>%
  mutate_at(vars(year), as.integer)

##SOY
soy_harv_Amunis <- soy_harv_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2001":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

soy_harv_Astates <- soy_harv_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

soy_harv_Astates_long <- soy_harv_Astates %>%
  gather(key = year, value = soy_ha, -state) %>%
  mutate_at(vars(year), as.integer)

soy_harv_Amunis_long <- soy_harv_Amunis %>%
  dplyr::select(-state) %>%
  gather(key = year, value = soy_ha, -muniID) %>%
  mutate_at(vars(year), as.integer)
```


```r
harv_muni_year <- left_join(maize_harv_Amunis_long, maize2_harv_Amunis_long, by = c("year", "muniID"))
 
harv_muni_year <- left_join(harv_muni_year, soy_harv_Amunis_long, by = c("year", "muniID"))

harv_muni_xxxx <- harv_muni_year %>%
  filter(year == 2018) %>%
  #filter(simulated == "TRUE") %>%
  #dplyr::select(muniID, maize_ha, soy_ha) %>%
  mutate(maize2_ha = replace(maize2_ha, is.na(maize2_ha),0)) %>%
  mutate(maize_ha = replace(maize_ha, is.na(maize_ha),0)) %>%
  mutate(soy_ha = replace(soy_ha, is.na(soy_ha),0)) %>%
  mutate(soy_ha = if_else(soy_ha > maize2_ha,soy_ha - maize2_ha, 0)) %>%
  mutate(total_ha = rowSums(dplyr::select(., ends_with("_ha")), na.rm=T)) %>%
  mutate(maize_prop = round(maize_ha / total_ha,3)) %>%
  mutate(soy_prop = round(soy_ha / total_ha,3)) %>%
  mutate(cum_ms_prop = rowSums(select(., "maize_prop", "soy_prop"))) %>%
  mutate(dc_prop = round(maize2_ha / total_ha,3))

write_csv(harv_muni_xxxx, "muni2018_harvestAreas_newDC.csv")
```



```r
#create new data frame
harv_state_year <- left_join(maize_harv_Astates_long, maize2_harv_Astates_long, by = c("year", "state"))

harv_state_year <- left_join(harv_state_year, soy_harv_Astates_long, by = c("year", "state"))

#add focal states indicator
harv_state_year <- harv_state_year %>%
  mutate(simulated = state %in% Fstate_vals) %>%
  #total ha 
  mutate(total_ha = rowSums(select(., ends_with("_ha")), na.rm=T)) %>%  
  #calculate double cropping
  mutate(suffsoy = if_else(!is.na(maize2_ha), soy_ha >= maize2_ha, F)) %>%
  #DC area is twice maize2
  mutate(DC_ha = if_else(suffsoy, 2 * maize2_ha, 
    if_else(!is.na(maize2_ha), 2 * soy_ha, 0))) %>% 
  #area of soy in DC
  mutate(soyDC_ha = if_else(suffsoy, maize2_ha, 
    if_else(!is.na(maize2_ha), soy_ha, 0))) %>% 
  #area of soy not in DC
  mutate(soyNDC_ha = if_else(suffsoy, soy_ha - maize2_ha, 
    if_else(!is.na(maize2_ha), 0, soy_ha))) %>% 
  mutate(m2DC_ha = if_else(suffsoy, maize2_ha, 
    if_else(!is.na(maize2_ha), soy_ha, 0))) %>%
  mutate(m2NDC_ha = if_else(suffsoy, 0,
    if_else(!is.na(maize2_ha), maize2_ha - soy_ha, 0))) %>%
  #proportion of m2 in DC
  mutate(m2DC_prop = if_else(maize2_ha > 0, m2DC_ha / maize2_ha, 0)) %>%
  #proportion of soy in DC
  mutate(soyDC_prop = if_else(soyDC_ha > 0, soyDC_ha / soy_ha, 0)) 

harv_state_year_props <- harv_state_year %>%
  select(state, year, total_ha, soyDC_prop, m2DC_prop) %>%
  mutate(maize_prop = 1) 

psy_long <- harv_state_year %>%
  select(-total_ha, -soyDC_prop, -m2DC_prop) %>%
  gather(key = commodity, value = ha, -state, -year, -simulated, -suffsoy)

psimy_long <- psy_long %>%
  group_by(simulated, year, commodity) %>%
  summarise(sumsim = sum(ha, na.rm=T))

harv_state_year_props
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["state"],"name":[1],"type":["chr"],"align":["left"]},{"label":["year"],"name":[2],"type":["int"],"align":["right"]},{"label":["total_ha"],"name":[3],"type":["dbl"],"align":["right"]},{"label":["soyDC_prop"],"name":[4],"type":["dbl"],"align":["right"]},{"label":["m2DC_prop"],"name":[5],"type":["dbl"],"align":["right"]},{"label":["maize_prop"],"name":[6],"type":["dbl"],"align":["right"]}],"data":[{"1":"11","2":"2001","3":"126707","4":"0.0000000000","5":"NA","6":"1"},{"1":"12","2":"2001","3":"29473","4":"0.0000000000","5":"NA","6":"1"},{"1":"13","2":"2001","3":"10685","4":"0.0000000000","5":"NA","6":"1"},{"1":"14","2":"2001","3":"10300","4":"0.0000000000","5":"NA","6":"1"},{"1":"15","2":"2001","3":"311034","4":"0.0000000000","5":"NA","6":"1"},{"1":"16","2":"2001","3":"1885","4":"0.0000000000","5":"NA","6":"1"},{"1":"17","2":"2001","3":"144346","4":"0.0000000000","5":"NA","6":"1"},{"1":"21","2":"2001","3":"534669","4":"0.0000000000","5":"NA","6":"1"},{"1":"22","2":"2001","3":"340691","4":"0.0000000000","5":"NA","6":"1"},{"1":"23","2":"2001","3":"603601","4":"0.0000000000","5":"NA","6":"1"},{"1":"24","2":"2001","3":"36999","4":"0.0000000000","5":"NA","6":"1"},{"1":"25","2":"2001","3":"18361","4":"0.0000000000","5":"NA","6":"1"},{"1":"26","2":"2001","3":"107645","4":"0.0000000000","5":"NA","6":"1"},{"1":"27","2":"2001","3":"38198","4":"0.0000000000","5":"NA","6":"1"},{"1":"28","2":"2001","3":"54114","4":"0.0000000000","5":"NA","6":"1"},{"1":"29","2":"2001","3":"1249465","4":"0.0000000000","5":"NA","6":"1"},{"1":"31","2":"2001","3":"1841518","4":"0.0000000000","5":"NA","6":"1"},{"1":"32","2":"2001","3":"46581","4":"0.0000000000","5":"NA","6":"1"},{"1":"33","2":"2001","3":"14328","4":"0.0000000000","5":"NA","6":"1"},{"1":"35","2":"2001","3":"1652535","4":"0.0000000000","5":"NA","6":"1"},{"1":"41","2":"2001","3":"5635367","4":"0.0000000000","5":"NA","6":"1"},{"1":"42","2":"2001","3":"1094965","4":"0.0000000000","5":"NA","6":"1"},{"1":"43","2":"2001","3":"4649421","4":"0.0000000000","5":"NA","6":"1"},{"1":"50","2":"2001","3":"1602900","4":"0.0000000000","5":"NA","6":"1"},{"1":"51","2":"2001","3":"3657828","4":"0.0000000000","5":"NA","6":"1"},{"1":"52","2":"2001","3":"2446616","4":"0.0000000000","5":"NA","6":"1"},{"1":"53","2":"2001","3":"63294","4":"0.0000000000","5":"NA","6":"1"},{"1":"11","2":"2002","3":"116542","4":"0.0000000000","5":"NA","6":"1"},{"1":"12","2":"2002","3":"32416","4":"0.0000000000","5":"NA","6":"1"},{"1":"13","2":"2002","3":"12042","4":"0.0000000000","5":"NA","6":"1"},{"1":"14","2":"2002","3":"13590","4":"0.0000000000","5":"NA","6":"1"},{"1":"15","2":"2002","3":"263315","4":"0.0000000000","5":"NA","6":"1"},{"1":"16","2":"2002","3":"1870","4":"0.0000000000","5":"NA","6":"1"},{"1":"17","2":"2002","3":"171537","4":"0.0000000000","5":"NA","6":"1"},{"1":"21","2":"2002","3":"562901","4":"0.0000000000","5":"NA","6":"1"},{"1":"22","2":"2002","3":"364896","4":"0.0000000000","5":"NA","6":"1"},{"1":"23","2":"2002","3":"703079","4":"0.0000000000","5":"NA","6":"1"},{"1":"24","2":"2002","3":"98839","4":"0.0000000000","5":"NA","6":"1"},{"1":"25","2":"2002","3":"149219","4":"0.0000000000","5":"NA","6":"1"},{"1":"26","2":"2002","3":"174473","4":"0.0000000000","5":"NA","6":"1"},{"1":"27","2":"2002","3":"58398","4":"0.0000000000","5":"NA","6":"1"},{"1":"28","2":"2002","3":"58854","4":"0.0000000000","5":"NA","6":"1"},{"1":"29","2":"2002","3":"1312758","4":"0.0000000000","5":"NA","6":"1"},{"1":"31","2":"2002","3":"1921432","4":"0.0000000000","5":"NA","6":"1"},{"1":"32","2":"2002","3":"53640","4":"0.0000000000","5":"NA","6":"1"},{"1":"33","2":"2002","3":"11424","4":"0.0000000000","5":"NA","6":"1"},{"1":"35","2":"2002","3":"1640707","4":"0.0000000000","5":"NA","6":"1"},{"1":"41","2":"2002","3":"5767255","4":"0.0000000000","5":"NA","6":"1"},{"1":"42","2":"2002","3":"1043387","4":"0.0000000000","5":"NA","6":"1"},{"1":"43","2":"2002","3":"4732383","4":"0.0000000000","5":"NA","6":"1"},{"1":"50","2":"2002","3":"1635067","4":"0.0000000000","5":"NA","6":"1"},{"1":"51","2":"2002","3":"4538176","4":"0.0000000000","5":"NA","6":"1"},{"1":"52","2":"2002","3":"2634073","4":"0.0000000000","5":"NA","6":"1"},{"1":"53","2":"2002","3":"64727","4":"0.0000000000","5":"NA","6":"1"},{"1":"11","2":"2003","3":"147235","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2003","3":"34067","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2003","3":"15400","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2003","3":"15800","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2003","3":"299868","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2003","3":"1382","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2003","3":"221756","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2003","3":"627928","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2003","3":"396451","4":"0.0013549090","5":"1.000000000","6":"1"},{"1":"23","2":"2003","3":"708541","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2003","3":"101399","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2003","3":"167577","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2003","3":"166456","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2003","3":"23734","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2003","3":"78519","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2003","3":"1523978","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"31","2":"2003","3":"2173630","4":"0.0325443553","5":"1.000000000","6":"1"},{"1":"32","2":"2003","3":"51295","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2003","3":"10685","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2003","3":"2091890","4":"0.5218460581","5":"1.000000000","6":"1"},{"1":"41","2":"2003","3":"7869911","4":"0.3767314796","5":"1.000000000","6":"1"},{"1":"42","2":"2003","3":"1113513","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2003","3":"5007267","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2003","3":"2711178","4":"0.4177654009","5":"1.000000000","6":"1"},{"1":"51","2":"2003","3":"6004028","4":"0.1605866219","5":"1.000000000","6":"1"},{"1":"52","2":"2003","3":"3124624","4":"0.1065166857","5":"1.000000000","6":"1"},{"1":"53","2":"2003","3":"81270","4":"0.1483452904","5":"1.000000000","6":"1"},{"1":"11","2":"2004","3":"177129","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2004","3":"43473","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2004","3":"15208","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2004","3":"24000","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2004","3":"329441","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2004","3":"1280","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2004","3":"325291","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2004","3":"711171","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2004","3":"434233","4":"0.0022852694","5":"1.000000000","6":"1"},{"1":"23","2":"2004","3":"656027","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2004","3":"87143","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2004","3":"163329","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2004","3":"210053","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2004","3":"45304","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2004","3":"91560","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2004","3":"1574616","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"31","2":"2004","3":"2444528","4":"0.0261988302","5":"1.000000000","6":"1"},{"1":"32","2":"2004","3":"50147","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2004","3":"11552","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2004","3":"2198020","4":"0.4417602708","5":"1.000000000","6":"1"},{"1":"41","2":"2004","3":"7594659","4":"0.2776068737","5":"1.000000000","6":"1"},{"1":"42","2":"2004","3":"1098092","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2004","3":"5183860","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2004","3":"2968271","4":"0.2935680125","5":"1.000000000","6":"1"},{"1":"51","2":"2004","3":"7012167","4":"0.1498404902","5":"1.000000000","6":"1"},{"1":"52","2":"2004","3":"3501082","4":"0.0821017657","5":"1.000000000","6":"1"},{"1":"53","2":"2004","3":"90035","4":"0.1300041681","5":"1.000000000","6":"1"},{"1":"11","2":"2005","3":"197325","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2005","3":"40892","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2005","3":"21199","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2005","3":"25000","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2005","3":"346668","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2005","3":"1568","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2005","3":"433482","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2005","3":"748287","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2005","3":"488856","4":"0.0006547568","5":"1.000000000","6":"1"},{"1":"23","2":"2005","3":"567056","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2005","3":"49763","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2005","3":"152855","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2005","3":"207174","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2005","3":"72895","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2005","3":"126551","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2005","3":"2019740","4":"0.4325034483","5":"1.000000000","6":"1"},{"1":"31","2":"2005","3":"2500276","4":"0.0249046580","5":"1.000000000","6":"1"},{"1":"32","2":"2005","3":"45900","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2005","3":"12026","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2005","3":"2179752","4":"0.4147681161","5":"1.000000000","6":"1"},{"1":"41","2":"2005","3":"6923038","4":"0.1781127104","5":"1.000000000","6":"1"},{"1":"42","2":"2005","3":"1085235","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2005","3":"5144858","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2005","3":"2910410","4":"0.1941623295","5":"1.000000000","6":"1"},{"1":"51","2":"2005","3":"8078409","4":"0.1491197578","5":"1.000000000","6":"1"},{"1":"52","2":"2005","3":"3462865","4":"0.0692697153","5":"1.000000000","6":"1"},{"1":"53","2":"2005","3":"102403","4":"0.1131819722","5":"1.000000000","6":"1"},{"1":"11","2":"2006","3":"228319","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2006","3":"37883","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2006","3":"22355","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2006","3":"23000","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2006","3":"348105","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2006","3":"1750","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2006","3":"403320","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2006","3":"747269","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2006","3":"495063","4":"0.0017240710","5":"1.000000000","6":"1"},{"1":"23","2":"2006","3":"639505","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2006","3":"78496","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2006","3":"183295","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2006","3":"262828","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2006","3":"72281","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2006","3":"139434","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2006","3":"1982288","4":"0.4451902361","5":"1.000000000","6":"1"},{"1":"31","2":"2006","3":"2257667","4":"0.0221762968","5":"1.000000000","6":"1"},{"1":"32","2":"2006","3":"39393","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2006","3":"10938","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2006","3":"1974400","4":"0.4087724642","5":"1.000000000","6":"1"},{"1":"41","2":"2006","3":"7291424","4":"0.2405941317","5":"1.000000000","6":"1"},{"1":"42","2":"2006","3":"1072997","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2006","3":"5271719","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2006","3":"3093568","4":"0.2837964070","5":"1.000000000","6":"1"},{"1":"51","2":"2006","3":"7839184","4":"0.1608051498","5":"1.000000000","6":"1"},{"1":"52","2":"2006","3":"3412396","4":"0.0894962431","5":"1.000000000","6":"1"},{"1":"53","2":"2006","3":"99657","4":"0.1143015932","5":"1.000000000","6":"1"},{"1":"11","2":"2007","3":"212589","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2007","3":"37165","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2007","3":"15114","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2007","3":"13400","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2007","3":"326272","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2007","3":"2070","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2007","3":"381620","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2007","3":"751353","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2007","3":"512110","4":"0.0006003821","5":"1.000000000","6":"1"},{"1":"23","2":"2007","3":"674391","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2007","3":"51290","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2007","3":"159884","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2007","3":"270652","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2007","3":"68806","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2007","3":"147712","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2007","3":"1951349","4":"0.4143807286","5":"1.000000000","6":"1"},{"1":"31","2":"2007","3":"2229529","4":"0.0345307610","5":"1.000000000","6":"1"},{"1":"32","2":"2007","3":"37634","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2007","3":"10250","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2007","3":"1612322","4":"0.4878469997","5":"1.000000000","6":"1"},{"1":"41","2":"2007","3":"8199491","4":"0.3595959198","5":"1.000000000","6":"1"},{"1":"42","2":"2007","3":"1080089","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2007","3":"5254226","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2007","3":"3337256","4":"0.4422877119","5":"1.000000000","6":"1"},{"1":"51","2":"2007","3":"7699449","4":"0.1922529679","5":"1.000000000","6":"1"},{"1":"52","2":"2007","3":"3281505","4":"0.1292894612","5":"1.000000000","6":"1"},{"1":"53","2":"2007","3":"101212","4":"0.1377979698","5":"1.000000000","6":"1"},{"1":"11","2":"2008","3":"233058","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2008","3":"63750","4":"1.0000000000","5":"0.001569859","6":"1"},{"1":"13","2":"2008","3":"12105","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2008","3":"14400","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2008","3":"336946","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2008","3":"3186","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2008","3":"418127","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2008","3":"774565","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2008","3":"536547","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"23","2":"2008","3":"675992","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2008","3":"73698","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2008","3":"180116","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2008","3":"275402","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2008","3":"78180","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2008","3":"160455","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2008","3":"1958877","4":"0.3635806139","5":"1.000000000","6":"1"},{"1":"31","2":"2008","3":"2230558","4":"0.0455788064","5":"1.000000000","6":"1"},{"1":"32","2":"2008","3":"37292","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2008","3":"8083","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2008","3":"1762915","4":"0.5153971936","5":"1.000000000","6":"1"},{"1":"41","2":"2008","3":"8439699","4":"0.3890073173","5":"1.000000000","6":"1"},{"1":"42","2":"2008","3":"1089132","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2008","3":"5177193","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2008","3":"3569429","4":"0.5021746147","5":"1.000000000","6":"1"},{"1":"51","2":"2008","3":"9144631","4":"0.2924529819","5":"1.000000000","6":"1"},{"1":"52","2":"2008","3":"3359811","4":"0.1254533790","5":"1.000000000","6":"1"},{"1":"53","2":"2008","3":"105463","4":"0.1697733618","5":"1.000000000","6":"1"},{"1":"11","2":"2009","3":"265117","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2009","3":"27633","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2009","3":"12404","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2009","3":"7800","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2009","3":"311797","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2009","3":"3468","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2009","3":"390434","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2009","3":"759071","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2009","3":"598212","4":"0.0004616406","5":"1.000000000","6":"1"},{"1":"23","2":"2009","3":"692607","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2009","3":"65750","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2009","3":"181830","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2009","3":"282687","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2009","3":"68418","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2009","3":"172941","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2009","3":"2039841","4":"0.3463151474","5":"1.000000000","6":"1"},{"1":"31","2":"2009","3":"2236473","4":"0.0312693395","5":"1.000000000","6":"1"},{"1":"32","2":"2009","3":"37671","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2009","3":"7759","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2009","3":"1262961","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"41","2":"2009","3":"8136238","4":"0.3246296589","5":"1.000000000","6":"1"},{"1":"42","2":"2009","3":"1033927","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2009","3":"5142100","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2009","3":"3311385","4":"0.4400251305","5":"1.000000000","6":"1"},{"1":"51","2":"2009","3":"9053683","4":"0.2673932190","5":"1.000000000","6":"1"},{"1":"52","2":"2009","3":"3600773","4":"0.1634945213","5":"1.000000000","6":"1"},{"1":"53","2":"2009","3":"94225","4":"0.1028723296","5":"1.000000000","6":"1"},{"1":"11","2":"2010","3":"280542","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2010","3":"39414","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2010","3":"14132","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2010","3":"7800","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2010","3":"287214","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"16","2":"2010","3":"3530","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2010","3":"436104","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"21","2":"2010","3":"871242","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2010","3":"630140","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"23","2":"2010","3":"553004","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2010","3":"20317","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2010","3":"73582","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2010","3":"176892","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2010","3":"43486","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2010","3":"364136","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2010","3":"2094696","4":"0.3473521750","5":"1.000000000","6":"1"},{"1":"31","2":"2010","3":"2217691","4":"0.0268762901","5":"1.000000000","6":"1"},{"1":"32","2":"2010","3":"28122","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2010","3":"7053","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2010","3":"1264592","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"41","2":"2010","3":"8096651","4":"0.3035247236","5":"1.000000000","6":"1"},{"1":"42","2":"2010","3":"1022680","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2010","3":"5170486","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2010","3":"3422542","4":"0.4711554224","5":"1.000000000","6":"1"},{"1":"51","2":"2010","3":"10116538","4":"0.3015478934","5":"1.000000000","6":"1"},{"1":"52","2":"2010","3":"3724853","4":"0.1721262676","5":"1.000000000","6":"1"},{"1":"53","2":"2010","3":"93751","4":"0.1019277282","5":"1.000000000","6":"1"},{"1":"11","2":"2011","3":"286778","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"12","2":"2011","3":"36771","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2011","3":"14630","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2011","3":"9500","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2011","3":"321550","4":"0.0471618027","5":"1.000000000","6":"1"},{"1":"16","2":"2011","3":"2854","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2011","3":"497370","4":"0.0375632365","5":"1.000000000","6":"1"},{"1":"21","2":"2011","3":"911836","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"22","2":"2011","3":"733940","4":"0.0008810848","5":"1.000000000","6":"1"},{"1":"23","2":"2011","3":"725301","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2011","3":"72739","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2011","3":"156523","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2011","3":"280210","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2011","3":"40730","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2011","3":"297700","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2011","3":"1900947","4":"0.2203742681","5":"1.000000000","6":"1"},{"1":"31","2":"2011","3":"2254097","4":"0.0559279993","5":"1.000000000","6":"1"},{"1":"32","2":"2011","3":"34756","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2011","3":"7756","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2011","3":"1541517","4":"0.5204242109","5":"1.000000000","6":"1"},{"1":"41","2":"2011","3":"8596070","4":"0.3582711788","5":"1.000000000","6":"1"},{"1":"42","2":"2011","3":"999662","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2011","3":"5174930","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2011","3":"3644879","4":"0.5210572617","5":"1.000000000","6":"1"},{"1":"51","2":"2011","3":"10225856","4":"0.2863880025","5":"1.000000000","6":"1"},{"1":"52","2":"2011","3":"4100547","4":"0.2237859408","5":"1.000000000","6":"1"},{"1":"53","2":"2011","3":"92392","4":"0.0912604368","5":"1.000000000","6":"1"},{"1":"11","2":"2012","3":"306857","4":"0.0034212831","5":"1.000000000","6":"1"},{"1":"12","2":"2012","3":"40802","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2012","3":"14518","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2012","3":"10900","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2012","3":"339121","4":"0.0292431863","5":"1.000000000","6":"1"},{"1":"16","2":"2012","3":"2535","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2012","3":"550916","4":"0.0926195594","5":"1.000000000","6":"1"},{"1":"21","2":"2012","3":"1072628","4":"0.1268604655","5":"1.000000000","6":"1"},{"1":"22","2":"2012","3":"714398","4":"0.0010812488","5":"1.000000000","6":"1"},{"1":"23","2":"2012","3":"498743","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2012","3":"6394","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2012","3":"15379","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2012","3":"73550","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2012","3":"4401","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2012","3":"163380","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2012","3":"1605769","4":"0.0801850036","5":"1.000000000","6":"1"},{"1":"31","2":"2012","3":"2354698","4":"0.0931505677","5":"1.000000000","6":"1"},{"1":"32","2":"2012","3":"32158","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2012","3":"6624","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2012","3":"1685286","4":"0.5064942913","5":"1.000000000","6":"1"},{"1":"41","2":"2012","3":"9493025","4":"0.4575567026","5":"1.000000000","6":"1"},{"1":"42","2":"2012","3":"970394","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2012","3":"5276353","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2012","3":"4233927","4":"0.6477943219","5":"1.000000000","6":"1"},{"1":"51","2":"2012","3":"12368209","4":"0.3791840062","5":"1.000000000","6":"1"},{"1":"52","2":"2012","3":"4636838","4":"0.2793309397","5":"1.000000000","6":"1"},{"1":"53","2":"2012","3":"114944","4":"0.1898637602","5":"1.000000000","6":"1"},{"1":"11","2":"2013","3":"417863","4":"0.5020957718","5":"1.000000000","6":"1"},{"1":"12","2":"2013","3":"45546","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2013","3":"11038","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2013","3":"20961","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2013","3":"433558","4":"0.1204241460","5":"1.000000000","6":"1"},{"1":"16","2":"2013","3":"6800","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2013","3":"673730","4":"0.0775703809","5":"1.000000000","6":"1"},{"1":"21","2":"2013","3":"1202665","4":"0.2347089520","5":"1.000000000","6":"1"},{"1":"22","2":"2013","3":"823957","4":"0.0007234014","5":"1.000000000","6":"1"},{"1":"23","2":"2013","3":"356221","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2013","3":"19228","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2013","3":"44196","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2013","3":"81009","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2013","3":"14394","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2013","3":"296578","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2013","3":"2061660","4":"0.2310506272","5":"1.000000000","6":"1"},{"1":"31","2":"2013","3":"2487210","4":"0.1030882710","5":"1.000000000","6":"1"},{"1":"32","2":"2013","3":"25269","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2013","3":"5980","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2013","3":"1711127","4":"0.4609125697","5":"1.000000000","6":"1"},{"1":"41","2":"2013","3":"9877270","4":"0.4463513239","5":"1.000000000","6":"1"},{"1":"42","2":"2013","3":"1005649","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2013","3":"5731798","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2013","3":"5014879","4":"0.7496482658","5":"1.000000000","6":"1"},{"1":"51","2":"2013","3":"14679092","4":"0.4198847566","5":"1.000000000","6":"1"},{"1":"52","2":"2013","3":"5036525","4":"0.2912437325","5":"1.000000000","6":"1"},{"1":"53","2":"2013","3":"124091","4":"0.3499619048","5":"1.000000000","6":"1"},{"1":"11","2":"2014","3":"460461","4":"0.5693308741","5":"1.000000000","6":"1"},{"1":"12","2":"2014","3":"43307","4":"1.0000000000","5":"0.550964187","6":"1"},{"1":"13","2":"2014","3":"8285","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2014","3":"22181","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"15","2":"2014","3":"478349","4":"0.1234851195","5":"1.000000000","6":"1"},{"1":"16","2":"2014","3":"19370","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2014","3":"917142","4":"0.1050564672","5":"1.000000000","6":"1"},{"1":"21","2":"2014","3":"1404196","4":"0.2579493462","5":"1.000000000","6":"1"},{"1":"22","2":"2014","3":"1004436","4":"0.0006700713","5":"1.000000000","6":"1"},{"1":"23","2":"2014","3":"472616","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2014","3":"23415","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2014","3":"67414","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2014","3":"284107","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2014","3":"27062","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"28","2":"2014","3":"325090","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2014","3":"2180224","4":"0.1936250410","5":"1.000000000","6":"1"},{"1":"31","2":"2014","3":"2741393","4":"0.1803667919","5":"1.000000000","6":"1"},{"1":"32","2":"2014","3":"22421","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2014","3":"4951","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2014","3":"1777849","4":"0.4428021084","5":"1.000000000","6":"1"},{"1":"41","2":"2014","3":"9467225","4":"0.3786631711","5":"1.000000000","6":"1"},{"1":"42","2":"2014","3":"996531","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2014","3":"5914405","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2014","3":"5323522","4":"0.7270964431","5":"1.000000000","6":"1"},{"1":"51","2":"2014","3":"15238036","4":"0.3799714856","5":"1.000000000","6":"1"},{"1":"52","2":"2014","3":"5701594","4":"0.3524308348","5":"1.000000000","6":"1"},{"1":"53","2":"2014","3":"175592","4":"0.4485555556","5":"1.000000000","6":"1"},{"1":"11","2":"2015","3":"543798","4":"0.5756811712","5":"1.000000000","6":"1"},{"1":"12","2":"2015","3":"39085","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"13","2":"2015","3":"5419","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2015","3":"29641","4":"0.0251889169","5":"1.000000000","6":"1"},{"1":"15","2":"2015","3":"602610","4":"0.1088483813","5":"1.000000000","6":"1"},{"1":"16","2":"2015","3":"13115","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2015","3":"1105049","4":"0.1360672071","5":"1.000000000","6":"1"},{"1":"21","2":"2015","3":"1352391","4":"0.1765837959","5":"1.000000000","6":"1"},{"1":"22","2":"2015","3":"1039794","4":"0.0007866973","5":"1.000000000","6":"1"},{"1":"23","2":"2015","3":"495874","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2015","3":"11253","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2015","3":"45803","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2015","3":"133653","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2015","3":"19508","4":"0.0143884892","5":"1.000000000","6":"1"},{"1":"28","2":"2015","3":"301870","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2015","3":"2420124","4":"0.1924368202","5":"1.000000000","6":"1"},{"1":"31","2":"2015","3":"2804031","4":"0.1927209833","5":"1.000000000","6":"1"},{"1":"32","2":"2015","3":"14419","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2015","3":"2613","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2015","3":"1970518","4":"0.4676541919","5":"1.000000000","6":"1"},{"1":"41","2":"2015","3":"9569394","4":"0.3608622010","5":"1.000000000","6":"1"},{"1":"42","2":"2015","3":"1013128","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2015","3":"6118634","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2015","3":"5692785","4":"0.7061835608","5":"1.000000000","6":"1"},{"1":"51","2":"2015","3":"16069516","4":"0.3912901869","5":"1.000000000","6":"1"},{"1":"52","2":"2015","3":"5813899","4":"0.3520982079","5":"1.000000000","6":"1"},{"1":"53","2":"2015","3":"172506","4":"0.5579564927","5":"1.000000000","6":"1"},{"1":"11","2":"2016","3":"530689","4":"0.4781229308","5":"1.000000000","6":"1"},{"1":"12","2":"2016","3":"37860","4":"1.0000000000","5":"0.072833212","6":"1"},{"1":"13","2":"2016","3":"4178","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2016","3":"29765","4":"0.0249635948","5":"1.000000000","6":"1"},{"1":"15","2":"2016","3":"659719","4":"0.0632645864","5":"1.000000000","6":"1"},{"1":"16","2":"2016","3":"17114","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2016","3":"1099487","4":"0.1093521097","5":"1.000000000","6":"1"},{"1":"21","2":"2016","3":"1193439","4":"0.0965681283","5":"1.000000000","6":"1"},{"1":"22","2":"2016","3":"1069201","4":"0.0397436262","5":"1.000000000","6":"1"},{"1":"23","2":"2016","3":"475714","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2016","3":"36866","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2016","3":"83798","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2016","3":"270949","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2016","3":"29888","4":"0.1020408163","5":"1.000000000","6":"1"},{"1":"28","2":"2016","3":"260903","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2016","3":"2295163","4":"0.0895756951","5":"1.000000000","6":"1"},{"1":"31","2":"2016","3":"3003605","4":"0.2120051025","5":"1.000000000","6":"1"},{"1":"32","2":"2016","3":"13998","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2016","3":"3244","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2016","3":"2163215","4":"0.5276194897","5":"1.000000000","6":"1"},{"1":"41","2":"2016","3":"10182390","4":"0.3929735227","5":"1.000000000","6":"1"},{"1":"42","2":"2016","3":"1021105","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2016","3":"6204594","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2016","3":"5800467","4":"0.6803821380","5":"1.000000000","6":"1"},{"1":"51","2":"2016","3":"16739375","4":"0.4035088851","5":"1.000000000","6":"1"},{"1":"52","2":"2016","3":"5997751","4":"0.3312808764","5":"1.000000000","6":"1"},{"1":"53","2":"2016","3":"182601","4":"0.5864268078","5":"1.000000000","6":"1"},{"1":"11","2":"2017","3":"495648","4":"0.6197291711","5":"1.000000000","6":"1"},{"1":"12","2":"2017","3":"34977","4":"1.0000000000","5":"0.066842105","6":"1"},{"1":"13","2":"2017","3":"3518","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2017","3":"25341","4":"0.3533244326","5":"1.000000000","6":"1"},{"1":"15","2":"2017","3":"767366","4":"0.1637459156","5":"1.000000000","6":"1"},{"1":"16","2":"2017","3":"20641","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2017","3":"1068709","4":"0.0988113898","5":"1.000000000","6":"1"},{"1":"21","2":"2017","3":"1281753","4":"0.2423008393","5":"1.000000000","6":"1"},{"1":"22","2":"2017","3":"1146905","4":"0.0729019623","5":"1.000000000","6":"1"},{"1":"23","2":"2017","3":"562831","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"24","2":"2017","3":"13481","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2017","3":"73929","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2017","3":"112633","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2017","3":"28598","4":"1.0000000000","5":"0.015806486","6":"1"},{"1":"28","2":"2017","3":"169262","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2017","3":"2083144","4":"0.1093654506","5":"1.000000000","6":"1"},{"1":"31","2":"2017","3":"2597012","4":"0.2403661423","5":"1.000000000","6":"1"},{"1":"32","2":"2017","3":"13122","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2017","3":"2757","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2017","3":"1828662","4":"0.4972616054","5":"1.000000000","6":"1"},{"1":"41","2":"2017","3":"7983626","4":"0.4294343995","5":"1.000000000","6":"1"},{"1":"42","2":"2017","3":"1031164","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2017","3":"6372076","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2017","3":"4452827","4":"0.6875861598","5":"1.000000000","6":"1"},{"1":"51","2":"2017","3":"14072099","4":"0.5066560773","5":"1.000000000","6":"1"},{"1":"52","2":"2017","3":"4965679","4":"0.4140761921","5":"1.000000000","6":"1"},{"1":"53","2":"2017","3":"135334","4":"0.6476285714","5":"1.000000000","6":"1"},{"1":"11","2":"2018","3":"485969","4":"0.4856955747","5":"1.000000000","6":"1"},{"1":"12","2":"2018","3":"30620","4":"1.0000000000","5":"0.457142857","6":"1"},{"1":"13","2":"2018","3":"3535","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"14","2":"2018","3":"46825","4":"0.1339262012","5":"1.000000000","6":"1"},{"1":"15","2":"2018","3":"784250","4":"0.1409454355","5":"1.000000000","6":"1"},{"1":"16","2":"2018","3":"21920","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"17","2":"2018","3":"1135481","4":"0.1169431827","5":"1.000000000","6":"1"},{"1":"21","2":"2018","3":"1341465","4":"0.1658155777","5":"1.000000000","6":"1"},{"1":"22","2":"2018","3":"1159134","4":"0.0655920284","5":"1.000000000","6":"1"},{"1":"23","2":"2018","3":"570293","4":"0.3625000000","5":"1.000000000","6":"1"},{"1":"24","2":"2018","3":"39026","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"25","2":"2018","3":"91265","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"26","2":"2018","3":"127577","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"27","2":"2018","3":"14048","4":"1.0000000000","5":"0.082113696","6":"1"},{"1":"28","2":"2018","3":"33496","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"29","2":"2018","3":"2120089","4":"0.1039196374","5":"1.000000000","6":"1"},{"1":"31","2":"2018","3":"2534195","4":"0.2617246656","5":"1.000000000","6":"1"},{"1":"32","2":"2018","3":"13921","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"33","2":"2018","3":"2504","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"35","2":"2018","3":"1833357","4":"0.4880118053","5":"1.000000000","6":"1"},{"1":"41","2":"2018","3":"7766806","4":"0.3799659827","5":"1.000000000","6":"1"},{"1":"42","2":"2018","3":"1005721","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"43","2":"2018","3":"6406036","4":"0.0000000000","5":"0.000000000","6":"1"},{"1":"50","2":"2018","3":"4612486","4":"0.6942867505","5":"1.000000000","6":"1"},{"1":"51","2":"2018","3":"13855095","4":"0.4626602901","5":"1.000000000","6":"1"},{"1":"52","2":"2018","3":"4782676","4":"0.3956778788","5":"1.000000000","6":"1"},{"1":"53","2":"2018","3":"135100","4":"0.5006993007","5":"1.000000000","6":"1"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>

Filter for 2001 only to get proportion of maize vs soy by state (for model initialisation)

```r
harv_state_2001 <- harv_state_year %>%
  filter(year == 2001) %>%
  filter(simulated == "TRUE") %>%
  select(state, maize_ha, soy_ha) %>%
  mutate(total_ha = rowSums(select(., ends_with("_ha")), na.rm=T)) %>%
  mutate(maize_prop = maize_ha / total_ha)

harv_state_2001
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["state"],"name":[1],"type":["chr"],"align":["left"]},{"label":["maize_ha"],"name":[2],"type":["dbl"],"align":["right"]},{"label":["soy_ha"],"name":[3],"type":["dbl"],"align":["right"]},{"label":["total_ha"],"name":[4],"type":["dbl"],"align":["right"]},{"label":["maize_prop"],"name":[5],"type":["dbl"],"align":["right"]}],"data":[{"1":"17","2":"62248","3":"82098","4":"144346","5":"0.4312416"},{"1":"29","2":"559465","3":"690000","4":"1249465","5":"0.4477636"},{"1":"31","2":"1209100","3":"632418","4":"1841518","5":"0.6565779"},{"1":"35","2":"1122535","3":"530000","4":"1652535","5":"0.6792806"},{"1":"41","2":"2817287","3":"2818080","4":"5635367","5":"0.4999296"},{"1":"42","2":"896112","3":"198853","4":"1094965","5":"0.8183933"},{"1":"43","2":"1672923","3":"2976498","4":"4649421","5":"0.3598132"},{"1":"50","2":"537874","3":"1065026","4":"1602900","5":"0.3355630"},{"1":"51","2":"536420","3":"3121408","4":"3657828","5":"0.1466499"},{"1":"52","2":"907628","3":"1538988","4":"2446616","5":"0.3709728"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>


```r
#plot areas through time
psimy_long_sim <- psimy_long %>% 
  filter(simulated == "TRUE") 
  
psimy_long_sim %>% 
  filter(commodity == "DC_ha" | commodity == "maize_ha" | commodity == "soyNDC_ha" | commodity == "m2NDC_ha") %>%
  ggplot(aes(x = year, y = sumsim, fill = commodity)) + 
  geom_bar(stat = "identity", colour="white") +
  scale_y_continuous(name = "Harvested Area (ha)", labels = scales::comma) +
  #facet_grid(.~state) +
  ggtitle("IBGE Data")
```

![](DoubleCropping_files/figure-html/unnamed-chunk-7-1.png)<!-- -->

```r
psimy_long_sim %>% 
  filter(commodity == "DC_ha" | commodity == "maize_ha" | commodity == "soyNDC_ha" | commodity == "m2NDC_ha") %>%
  ggplot(aes(x = year, y = sumsim, fill = commodity)) + 
  geom_bar(stat = "identity", colour="white", position="fill") +
  scale_y_continuous(name = "Harvested Area (ha)", labels = scales::percent_format()) +
  #facet_grid(.~state) +
  ggtitle("IBGE Data")
```

![](DoubleCropping_files/figure-html/unnamed-chunk-7-2.png)<!-- -->

```r
psimy_long_sim %>% 
  ggplot(aes(x = year, y = sumsim, colour=commodity)) + 
  geom_line(size = 1) +
  scale_y_continuous(name = "Harvested Area (ha)", labels = scales::comma) +
  #facet_grid(.~state) +
  ggtitle("IBGE Data")
```

![](DoubleCropping_files/figure-html/unnamed-chunk-7-3.png)<!-- -->


## Production

DC production is maize2 production + proportion of soy production in DC


```r
#maize data are by municiaplity for all states (Amunis)
maize_prod_Amunis_Data <- read_excel("ProductionData/maize_brazil.xlsx", sheet = "Production (tons)", skip = 1, na = c("", "-", "..."))

#maize data are by municiaplity for all states (Amunis)
maize2_prod_Amunis_Data <- read_excel("ProductionData/maize2_brazil.xlsx", sheet = "Production (tons)", skip = 1, na = c("", "-", "..."), col_types = c("numeric", "guess","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric"))  #need to specify for 2010 column

#maize data are by municiaplity for all states (Amunis)
soy_prod_Amunis_Data <- read_excel("ProductionData/soybean_brazil.xlsx", sheet = "Production (Tons)", skip = 1, na = c("", "-", "..."))
```


```r
#Manipulate data

#MAIZE
#tonss the same data strucutre (with some differences in unit conversions - could write function to cover both?) 
maize_prod_Amunis <- maize_prod_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2001":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

maize_prod_Astates <- maize_prod_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

maize_prod_Astates_long <- maize_prod_Astates %>%
  gather(key = year, value = maize_tons, -state) %>%
  mutate_at(vars(year), as.integer)


#MAIZE2
maize2_prod_Amunis <- maize2_prod_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2003":"2015"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

maize2_prod_Astates <- maize2_prod_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

maize2_prod_Astates_long <- maize2_prod_Astates %>%
  gather(key = year, value = maize2_tons, -state) %>%
  mutate_at(vars(year), as.integer)


##SOY
soy_prod_Amunis <- soy_prod_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2001":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

soy_prod_Astates <- soy_prod_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

soy_prod_Astates_long <- soy_prod_Astates %>%
  gather(key = year, value = soy_tons, -state) %>%
  mutate_at(vars(year), as.integer)
```



```r
#create new data frame
prod_state_year <- left_join(maize_prod_Astates_long, maize2_prod_Astates_long, by = c("year", "state"))

prod_state_year <- left_join(prod_state_year, soy_prod_Astates_long, by = c("year", "state"))
```



```r
prod_harv <- left_join(prod_state_year, harv_state_year_props, by = c("year", "state")) 
```




## Planted Area

Data from IBGE

```r
##Load Area Planted Data

#maize data are by municiaplity for all states (Amunis)
maize_plant_Amunis_Data <- read_excel("ProductionData/maize_brazil.xlsx", sheet = "Planted area (hectares)", skip = 1, na = c("", "-", "..."))

#maize data are by municiaplity for all states (Amunis)
maize2_plant_Amunis_Data <- read_excel("ProductionData/maize2_brazil.xlsx", sheet = "Planted area (hectares)", skip = 1, na = c("", "-", "..."), col_types = c("numeric", "guess","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric","numeric"))  #need to specify for 2010 column  

#maize data are by municiaplity for all states (Amunis)
soy_plant_Amunis_Data <- read_excel("ProductionData/soybean_brazil.xlsx", sheet = "Planted area (hectares)", skip = 1, na = c("", "-", "..."))


Fstate_vals <- c(17,	29,	31,	35,	41,	42,	43,	50,	51,	52)
Fstate_abbrev <- c("TO", "BA", "MG", "SP", "PR",  "SC", "RS", "MS", "MT", "GO")
```



```r
#Manipulate data

#MAIZE
#has the same data strucutre (with some differences in unit conversions - could write function to cover both?) 
maize_plant_Amunis <- maize_plant_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2001":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

maize_plant_Astates <- maize_plant_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

maize_plant_Astates_long <- maize_plant_Astates %>%
  gather(key = year, value = maize_ha, -state) %>%
  mutate_at(vars(year), as.integer)

maize_plant_Amunis_long <- maize_plant_Amunis %>%
  dplyr::select(-state) %>%
  gather(key = year, value = maize_ha, -muniID) %>%
  mutate_at(vars(year), as.integer)

#MAIZE2
maize2_plant_Amunis <- maize2_plant_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2003":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

maize2_plant_Astates <- maize2_plant_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

maize2_plant_Astates_long <- maize2_plant_Astates %>%
  gather(key = year, value = maize2_ha, -state) %>%
  mutate_at(vars(year), as.integer)

maize2_plant_Amunis_long <- maize2_plant_Amunis %>%
  dplyr::select(-state) %>%
  gather(key = year, value = maize2_ha, -muniID) %>%
  mutate_at(vars(year), as.integer)

##SOY
soy_plant_Amunis <- soy_plant_Amunis_Data %>%
  rename(muniID = `IBGE CODE`) %>%
  filter(!is.na(muniID)) %>%   #safer way to remove text line in muniID
  mutate(state = substr(muniID, 1, 2)) %>%     #extract the muniID
  mutate_at(vars("2001":"2018"), as.numeric) %>%  #convert values to numeric
  dplyr::select(-Municipality)   #drop unwanted columns

soy_plant_Astates <- soy_plant_Amunis %>%
  group_by(state) %>%
  summarise_all(sum, na.rm=T) %>%  
  dplyr::select(-muniID)   #drop unwanted columns

soy_plant_Astates_long <- soy_plant_Astates %>%
  gather(key = year, value = soy_ha, -state) %>%
  mutate_at(vars(year), as.integer)

soy_plant_Amunis_long <- soy_plant_Amunis %>%
  dplyr::select(-state) %>%
  gather(key = year, value = soy_ha, -muniID) %>%
  mutate_at(vars(year), as.integer)
```


```r
plant_muni_year <- left_join(maize_plant_Amunis_long, maize2_plant_Amunis_long, by = c("year", "muniID"))
 
plant_muni_year <- left_join(plant_muni_year, soy_plant_Amunis_long, by = c("year", "muniID"))

plant_muni_xxxx <- plant_muni_year %>%
  filter(year == 2018) %>%
  #filter(simulated == "TRUE") %>%
  #dplyr::select(muniID, maize_ha, soy_ha) %>%
  mutate(maize2_ha = replace(maize2_ha, is.na(maize2_ha),0)) %>%
  mutate(maize_ha = replace(maize_ha, is.na(maize_ha),0)) %>%
  mutate(soy_ha = replace(soy_ha, is.na(soy_ha),0)) %>%
  mutate(soy_ha = if_else(soy_ha > maize2_ha,soy_ha - maize2_ha, 0)) %>%
  mutate(total_ha = rowSums(dplyr::select(., ends_with("_ha")), na.rm=T)) %>%
  mutate(maize_prop = round(maize_ha / total_ha,3)) %>%
  mutate(soy_prop = round(soy_ha / total_ha,3)) %>%
  mutate(cum_ms_prop = rowSums(select(., "maize_prop", "soy_prop"))) %>%
  mutate(dc_prop = round(maize2_ha / total_ha,3))
  
write_csv(plant_muni_xxxx, "muni2018_plantedAreas_newDC.csv")
```

